
The modulefinder module does not handle relative directories properly.  The error I found is
when one subpackage attempts to import from a sibling subpackage using the form

    from ..language import (
        DirectiveDefinitionNode,
        ...
    )
    
This example is from:

https://github.com/graphql-python/graphql-core-next/blob/c423676addc4acf16d04aa4773a3b06a7a529b7a/src/graphql/utilities/build_ast_schema.py#L3

I've created this example to reproduce and this file to keep my notes.

I've created the following files to be analyzed:

* a.py - The main script to be analyzed
* b - a package
  * x - has a function `testing` that b.c imports
  * c - a subpackage with a function imported by a.py using `from ..x import (testing)`
  
If you run a.py, it will work fine.  It imports b.c, which in turn imports b.x (via ..x), and
everything works.  It will print a message from the b.x. function.

The test.py file will use ModuleFinder to analyze a.py and it will report that "x.testing" is
missing.
  
First, note that `testing` is not even a module.  When analyzing the import line, ModuleFinder
attempts to import everything in the list, marks items like variables and functions as "bad
modules".  This is normal and in any_missing_maybe will weed out the variables and functions by
comparing them the parent's (x's) global names.

In this case, however, it is incorrectly recorded as "x.testing" instead of "b.x.testing".
When the import was attempted, it correctly resolved the source as "b.x" and imported the
modules.  It failed because `testing` is a function not a module, but that is normal.

It raises an ImportError which is caught in `_safe_import_hook`:

    except ImportError as msg:
        self.msg(2, "ImportError:", str(msg))
        fullname = name + "." + sub
        self._add_badmodule(fullname, caller)

At this point it has lost the correctly resolved "b.x" and `name` is just "x".

I've tested this in 3.7 and 3.8 and both fail.
